.. _pecan_deploy:

:mod:`pecan.deploy` -- Pecan Deploy
===========================================

The :mod:`pecan.deploy` module includes fixtures to help deploy Pecan
applications.

.. automodule:: pecan.deploy
  :members:
  :show-inheritance:
